==> jc-1.4.0.tar.gz: gnu/java/nio/FileLockImpl.h <==
// public class gnu.java.nio.FileLockImpl

// class file dependencies
// @dep_class 9c77c4dd024ccefd gnu_java_nio_FileLockImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 48ccbfd606464fc6 java_nio_channels_FileLock

// header file dependencies
// @dep_header java_nio_channels_FileLock

#include "java/nio/channels/FileLock.h"

#ifndef _JC_gnu_java_nio_FileLockImpl_H_
#define _JC_gnu_java_nio_FileLockImpl_H_

// Forward structure declarations
struct _jc_gnu_java_nio_channels_FileChannelImpl$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_nio_FileLockImpl$sub_refs	_jc_gnu_java_nio_FileLockImpl$sub_refs;
typedef struct _jc_gnu_java_nio_FileLockImpl$sub_nonrefs	_jc_gnu_java_nio_FileLockImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_FileLockImpl$refs	_jc_gnu_java_nio_FileLockImpl$refs;
typedef struct _jc_gnu_java_nio_FileLockImpl$nonrefs	_jc_gnu_java_nio_FileLockImpl$nonrefs;
typedef struct _jc_gnu_java_nio_FileLockImpl$object	_jc_gnu_java_nio_FileLockImpl$object;

typedef const struct _jc_gnu_java_nio_FileLockImpl$vmethods	_jc_gnu_java_nio_FileLockImpl$vmethods;
typedef const struct _jc_gnu_java_nio_FileLockImpl$vtable	_jc_gnu_java_nio_FileLockImpl$vtable;
typedef const struct _jc_gnu_java_nio_FileLockImpl$vtype	_jc_gnu_java_nio_FileLockImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_FileLockImpl$method$_init$eefde49700bb8506(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *, struct _jc_gnu_java_nio_channels_FileChannelImpl$object *, jlong, jlong, jboolean);

// Virtual methods
extern void _jc_gnu_java_nio_FileLockImpl$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *);
extern jboolean _jc_gnu_java_nio_FileLockImpl$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *);
extern void _jc_gnu_java_nio_FileLockImpl$method$release$63a21b398a34f6bd(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_FileLockImpl$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_java_nio_FileLockImpl$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_java_nio_FileLockImpl$method_info$release$63a21b398a34f6bd;

// Virtual methods structure
struct _jc_gnu_java_nio_FileLockImpl$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *);
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *);
	void	(*release$63a21b398a34f6bd)(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *);
};

// Vtable
struct _jc_gnu_java_nio_FileLockImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_FileLock$vmethods	java_nio_channels_FileLock;
	_jc_gnu_java_nio_FileLockImpl$vmethods	gnu_java_nio_FileLockImpl;
};

// Vtype
struct _jc_gnu_java_nio_FileLockImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_FileLockImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_FileLockImpl$sub_refs {
	struct _jc_gnu_java_nio_channels_FileChannelImpl$object	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_FileLockImpl$refs {
    _jc_gnu_java_nio_FileLockImpl$sub_refs	gnu_java_nio_FileLockImpl;
    _jc_java_nio_channels_FileLock$sub_refs	java_nio_channels_FileLock;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_FileLockImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_FileLockImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_FileLock$sub_nonrefs	java_nio_channels_FileLock;
    _jc_gnu_java_nio_FileLockImpl$sub_nonrefs	gnu_java_nio_FileLockImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_FileLockImpl$object {
	_jc_gnu_java_nio_FileLockImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_FileLockImpl$vtype	*vtype;
	_jc_gnu_java_nio_FileLockImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_FileLockImpl$vtype _jc_gnu_java_nio_FileLockImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_FileLockImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_FileLockImpl$class_object;

#endif	/* _JC_gnu_java_nio_FileLockImpl_H_ */

==> jc-1.4.5.tar.gz: gnu/java/nio/FileLockImpl.h <==
// public class gnu.java.nio.FileLockImpl

// class file dependencies
// @dep_class 9c77c4dd024ccefd gnu_java_nio_FileLockImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 48ccbfd606464fc6 java_nio_channels_FileLock

// header file dependencies
// @dep_header java_nio_channels_FileLock

#include "java/nio/channels/FileLock.h"

#ifndef _JC_gnu_java_nio_FileLockImpl_H_
#define _JC_gnu_java_nio_FileLockImpl_H_

// Forward structure declarations
struct _jc_gnu_java_nio_channels_FileChannelImpl$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_nio_FileLockImpl$sub_refs	_jc_gnu_java_nio_FileLockImpl$sub_refs;
typedef struct _jc_gnu_java_nio_FileLockImpl$sub_nonrefs	_jc_gnu_java_nio_FileLockImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_FileLockImpl$refs	_jc_gnu_java_nio_FileLockImpl$refs;
typedef struct _jc_gnu_java_nio_FileLockImpl$nonrefs	_jc_gnu_java_nio_FileLockImpl$nonrefs;
typedef struct _jc_gnu_java_nio_FileLockImpl$object	_jc_gnu_java_nio_FileLockImpl$object;

typedef const struct _jc_gnu_java_nio_FileLockImpl$vmethods	_jc_gnu_java_nio_FileLockImpl$vmethods;
typedef const struct _jc_gnu_java_nio_FileLockImpl$vtable	_jc_gnu_java_nio_FileLockImpl$vtable;
typedef const struct _jc_gnu_java_nio_FileLockImpl$vtype	_jc_gnu_java_nio_FileLockImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_FileLockImpl$method$_init$eefde49700bb8506(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *, struct _jc_gnu_java_nio_channels_FileChannelImpl$object *, jlong, jlong, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_nio_FileLockImpl$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_nio_FileLockImpl$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_FileLockImpl$method$release$63a21b398a34f6bd(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_FileLockImpl$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_java_nio_FileLockImpl$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_java_nio_FileLockImpl$method_info$release$63a21b398a34f6bd;

// Virtual methods structure
struct _jc_gnu_java_nio_FileLockImpl$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *) _JC_JCNI_ATTR;
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *) _JC_JCNI_ATTR;
	void	(*release$63a21b398a34f6bd)(_jc_env *, struct _jc_gnu_java_nio_FileLockImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_FileLockImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_FileLock$vmethods	java_nio_channels_FileLock;
	_jc_gnu_java_nio_FileLockImpl$vmethods	gnu_java_nio_FileLockImpl;
};

// Vtype
struct _jc_gnu_java_nio_FileLockImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_FileLockImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_FileLockImpl$sub_refs {
	struct _jc_gnu_java_nio_channels_FileChannelImpl$object	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_FileLockImpl$refs {
    _jc_gnu_java_nio_FileLockImpl$sub_refs	gnu_java_nio_FileLockImpl;
    _jc_java_nio_channels_FileLock$sub_refs	java_nio_channels_FileLock;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_FileLockImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_FileLockImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_FileLock$sub_nonrefs	java_nio_channels_FileLock;
    _jc_gnu_java_nio_FileLockImpl$sub_nonrefs	gnu_java_nio_FileLockImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_FileLockImpl$object {
	_jc_gnu_java_nio_FileLockImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_FileLockImpl$vtype	*vtype;
	_jc_gnu_java_nio_FileLockImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_FileLockImpl$vtype _jc_gnu_java_nio_FileLockImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_FileLockImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_FileLockImpl$class_object;

#endif	/* _JC_gnu_java_nio_FileLockImpl_H_ */
